@@ -20,6 +20,8 @@ import importlib
 import logging
 import pytz
 
+import six
+
 from .common import (  # noqa: F401
     URL, HTML, FORM, RECEIVED, ACCEPTED, PAID, DENIED,
     CANCELED, CANCELLED, ERROR, WAITING, force_text,
@@ -31,6 +33,9 @@ __all__ = ['Payment', 'URL', 'HTML', 'FORM', 'SIPS', 'SYSTEMPAY', 'SPPLUS',
            'DENIED', 'CANCELED', 'CANCELLED', 'ERROR', 'WAITING',
            'get_backends', 'PAYFIP_WS']
 
+if six.PY3:
+    __all__.extend(['KEYWARE', 'MOLLIE'])
+
 SIPS = 'sips'
 SIPS2 = 'sips2'
 SYSTEMPAY = 'systempayv2'
@@ -41,6 +46,8 @@ OGONE = 'ogone'
 PAYBOX = 'paybox'
 PAYZEN = 'payzen'
 PAYFIP_WS = 'payfip_ws'
+KEYWARE = 'keyware'
+MOLLIE = 'mollie'
 
 logger = logging.getLogger(__name__)
 
@@ -51,7 +58,7 @@ def get_backend(kind):
     return module.Payment
 
 __BACKENDS = [DUMMY, SIPS, SIPS2, SYSTEMPAY, SPPLUS, OGONE, PAYBOX, PAYZEN,
-              TIPI, PAYFIP_WS]
+              TIPI, PAYFIP_WS, KEYWARE, MOLLIE]
 
 
 def get_backends():
