@@ -19,6 +19,7 @@ import os
 import random
 import logging
 from datetime import date
+from decimal import ROUND_DOWN, Decimal
 
 import six
 
@@ -167,6 +168,20 @@ class PaymentCommon(object):
                 os.close(fd)
                 return id
 
+    @staticmethod
+    def clean_amount(amount, min_amount=0, max_amount=None, cents=True):
+        try:
+            amount = Decimal(amount)
+        except ValueError:
+            raise ValueError('invalid amount %s: it must be a decimal integer with two digits '
+                             'at most after the decimal point', amount)
+        if int(amount) < min_amount or (max_amount and  int(amount) > max_amount):
+            raise ValueError('amount %s is not in range [%s, %s]' % (amount, min_amount, max_amount))
+        if cents:
+            amount *= Decimal('100')  # convert to cents
+            amount = amount.to_integral_value(ROUND_DOWN)
+        return str(amount)
+
 
 class Form(object):
     def __init__(self, url, method, fields, encoding='utf-8',
