@@ -86,11 +86,13 @@ class Payment(PaymentCommon):
                 'caption': 'name of the requesting service, '
                            'to present in the user interface',
                 'type': str,
+                'default': 'origin',
             },
             {
                 'name': 'siret',
                 'caption': 'dummy siret parameter',
                 'type': str,
+                'default': 'siret',
             },
             {
                 'name': 'consider_all_response_signed',
