@@ -25,7 +25,6 @@ import requests
 
 import pytz
 
-from decimal import Decimal, ROUND_DOWN
 from Crypto.Signature import PKCS1_v1_5
 from Crypto.PublicKey import RSA
 from Crypto.Hash import SHA
@@ -287,7 +286,7 @@ class Payment(PaymentCommon):
         d['PBX_SITE'] = force_text(self.site)
         d['PBX_RANG'] = force_text(self.rang).strip()[-2:]
         d['PBX_IDENTIFIANT'] = force_text(self.identifiant)
-        d['PBX_TOTAL'] = (amount * Decimal(100)).to_integral_value(ROUND_DOWN)
+        d['PBX_TOTAL'] = self.clean_amount(amount)
         d['PBX_DEVISE'] = force_text(self.devise)
         transaction_id = kwargs.get('transaction_id') or \
             self.transaction_id(12, string.digits, 'paybox', self.site,
@@ -410,7 +409,7 @@ class Payment(PaymentCommon):
             'RANG': self.rang.strip(),
             'CLE': force_text(self.cle),
             'NUMQUESTION': bank_data['numero_transaction'][0].zfill(10),
-            'MONTANT': (amount * Decimal(100)).to_integral_value(ROUND_DOWN),
+            'MONTANT': self.clean_amount(amount),
             'DEVISE': force_text(self.devise),
             'NUMTRANS': bank_data['numero_transaction'][0],  # paybox transaction number
             'NUMAPPEL': bank_data['numero_appel'][0],
