@@ -191,20 +191,7 @@ class Payment(PaymentCommon):
         return '%s%010d' % (isonow(), random.randint(1, 1000000000))
 
     def request(self, amount, email, **kwargs):
-        try:
-            montant = Decimal(amount)
-            # MONTANT must be sent as centimes
-            montant = montant * Decimal('100')
-            montant = montant.to_integral_value(ROUND_DOWN)
-            if not (Decimal('0') < montant <= Decimal('10000000')):
-                raise ValueError('MONTANT > 100000 euros or < 0')
-            montant = str(montant)
-        except ValueError:
-            raise ValueError(
-                'MONTANT invalid format, must be '
-                'a decimal integer with less than 4 digits '
-                'before and 2 digits after the decimal point '
-                ', here it is %s' % repr(amount))
+        montant = self.clean_amount(amount, max_amount=100000)
 
         numcli = self.numcli
         urlnotif = self.automatic_return_url
