@@ -18,7 +18,6 @@
 from six.moves.urllib import parse as urlparse
 import string
 import subprocess
-from decimal import Decimal
 import logging
 import os
 import os.path
@@ -163,7 +162,7 @@ class Payment(PaymentCommon):
         params[TRANSACTION_ID] = transaction_id
         params[ORDER_ID] = orderid or str(uuid.uuid4())
         params[ORDER_ID] = params[ORDER_ID].replace('-', '')
-        params['amount'] = str(int(Decimal(amount) * 100))
+        params['amount'] = self.clean_amount(amount)
         if email:
             params['customer_email'] = email
         normal_return_url = self.normal_return_url
