@@ -205,7 +205,7 @@ class Payment(PaymentCommon):
             data['statementReference'] = force_text(info1)
         else:
             data['statementReference'] = data['transactionReference']
-        data['amount'] = force_text(int(Decimal(amount) * 100))
+        data['amount'] = self.clean_amount(amount)
         if email:
             data['billingContact.email'] = email
         if 'capture_day' in kwargs:
@@ -323,13 +323,13 @@ class Payment(PaymentCommon):
 
     def cancel(self, amount, bank_data, **kwargs):
         data = {}
-        data['operationAmount'] = force_text(int(Decimal(amount) * 100))
+        data['operationAmount'] = self.clean_amount(amount)
         data['transactionReference'] = bank_data.get('transactionReference')
         return self.perform_cash_management_operation('cancel', data)
 
     def validate(self, amount, bank_data, **kwargs):
         data = {}
-        data['operationAmount'] = force_text(int(Decimal(amount) * 100))
+        data['operationAmount'] = self.clean_amount(amount)
         data['transactionReference'] = bank_data.get('transactionReference')
         return self.perform_cash_management_operation('validate', data)
 
