@@ -1,8 +1,23 @@
 # -*- coding: utf-8 -*-
+# eopayment - online payment library
+# Copyright (C) 2011-2020 Entr'ouvert
+#
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Affero General Public License as published
+# by the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import pytz
 import datetime as dt
 import hashlib
-import logging
 import string
 from six.moves.urllib import parse as urlparse
 import warnings
@@ -33,6 +48,7 @@ VADS_SITE_ID = 'vads_site_id'
 VADS_TRANS_ID = 'vads_trans_id'
 SIGNATURE = 'signature'
 VADS_CTX_MODE = 'vads_ctx_mode'
+VADS_EFFECTIVE_CREATION_DATE = 'vads_effective_creation_date'
 
 
 def isonow():
@@ -40,6 +56,14 @@ def isonow():
         .replace('T', '').replace(':', '')[:14]
 
 
+def parse_utc(value):
+    try:
+        naive_dt = dt.datetime.strptime(value, '%Y%m%d%H%M%S')
+    except ValueError:
+        return None
+    return pytz.utc.localize(naive_dt)
+
+
 class Parameter:
     def __init__(self, name, ptype, code, max_length=None, length=None,
                  needed=False, default=None, choices=None, description=None,
@@ -277,7 +301,8 @@ class Payment(PaymentCommon):
 
     def request(self, amount, name=None, first_name=None, last_name=None,
                 address=None, email=None, phone=None, orderid=None, info1=None,
-                info2=None, info3=None, next_url=None, manual_validation=None, **kwargs):
+                info2=None, info3=None, next_url=None, manual_validation=None,
+                **kwargs):
         '''
            Create the URL string to send a request to SystemPay
         '''
@@ -323,8 +348,8 @@ class Payment(PaymentCommon):
             ptype = 'an-'
             p = Parameter(name, ptype, 13, max_length=32)
             if not p.check_value(orderid):
-                raise ValueError('%s value %s is not of the type %s' % (name,
-                                orderid, ptype))
+                raise ValueError(
+                    '%s value %s is not of the type %s' % (name, orderid, ptype))
             kwargs[name] = orderid
 
         transaction_id = self.transaction_id(6, string.digits, 'systempay',
@@ -417,6 +442,9 @@ class Payment(PaymentCommon):
         transaction_id = '%s_%s' % (copy[VADS_TRANS_DATE], copy[VADS_TRANS_ID])
         # the VADS_AUTH_NUMBER is the number to match payment in bank logs
         copy[self.BANK_ID] = copy.get(VADS_AUTH_NUMBER, '')
+        transaction_date = None
+        if VADS_EFFECTIVE_CREATION_DATE in fields:
+            transaction_date = parse_utc(fields[VADS_EFFECTIVE_CREATION_DATE])
         response = PaymentResponse(
             result=result,
             signed=signature_result,
@@ -424,6 +452,7 @@ class Payment(PaymentCommon):
             order_id=transaction_id,
             transaction_id=copy.get(VADS_AUTH_NUMBER),
             bank_status=' - '.join(bank_status),
+            transaction_date=transaction_date,
             test=test)
         return response
 
