@@ -260,7 +260,7 @@ class PayboxTests(TestCase):
                     'CLE': 'cancelling_key',
                     'VERSION': '00103',
                     'TYPE': operation_code,
-                    'MONTANT': Decimal('1000'),
+                    'MONTANT': '1000',
                     'NUMAPPEL': '30310733',
                     'NUMTRANS': '13957441',
                     'NUMQUESTION': '0013957441',
